@@ -107,13 +107,41 @@ class Service(k8s_object.KubernetesObject):
   def serving_revisions(self):
     return [t.revisionName for t in self.status.traffic if t.percent]
 
+  def _ShouldIncludeInLatestPercent(self, target):
+    """Returns True if the target's percent is part of the latest percent."""
+    is_latest_by_name = (
+        self.status.latestReadyRevisionName and
+        target.revisionName == self.status.latestReadyRevisionName)
+    return target.percent and (target.latestRevision or is_latest_by_name)
+
+  @property
+  def latest_percent_traffic(self):
+    """The percent of traffic the latest ready revision is serving."""
+    return sum(
+        target.percent
+        for target in self.status.traffic
+        if self._ShouldIncludeInLatestPercent(target))
+
   @property
   def domain(self):
-    return self._m.status.url or self._m.status.domain
+    if self._m.status.url:
+      return self._m.status.url
+    try:
+      return self._m.status.domain
+    except AttributeError:
+      # `domain` field only exists in v1alpha1 so this could be thrown if using
+      # another api version
+      return None
 
   @domain.setter
   def domain(self, domain):
-    self._m.status.url = self._m.status.domain = domain
+    self._m.status.url = domain
+    try:
+      self._m.status.domain = domain
+    except AttributeError:
+      # `domain` field only exists in v1alpha1 so this could be thrown if using
+      # another api version
+      return None
 
   def ReadySymbolAndColor(self):
     if (self.ready is False and  # pylint: disable=g-bool-id-comparison
