@@ -37,6 +37,24 @@ _DETAILED_SOURCE_SNAPSHOT_HELP = """\
       size of the disks.
 """
 
+_DETAILED_SOURCE_IN_PLACE_SNAPSHOT_HELP = """\
+      Source in place snapshot used to create the disks.
+"""
+
+_SOURCE_DISK_DETAILED_HELP = """\
+      Source disk used to create the disks. It is safe to
+      delete a source disk after a disk has been created from the
+      source disk. To get a list of disks in your current project,
+      run `gcloud compute disks list`. This flag is mutually
+      exclusive with *--image* and *--source-snapshot*.
+
+      When using this option, the size of the disks must be at least
+      as large as the source disk size. Use *--size* to adjust the
+      size of the disks.
+
+      Source disk must be in the same zone/region as the disk to be created.
+"""
+
 
 DEFAULT_LIST_FORMAT = """\
     table(
@@ -98,3 +116,27 @@ SOURCE_SNAPSHOT_ARG = compute_flags.ResourceArgument(
     global_collection='compute.snapshots',
     short_help='Source snapshot used to create the disks.',
     detailed_help=_DETAILED_SOURCE_SNAPSHOT_HELP,)
+
+SOURCE_IN_PLACE_SNAPSHOT_ARG = compute_flags.ResourceArgument(
+    resource_name='source in place snapshot',
+    completer=compute_completers.InPlaceSnapshotsCompleter,
+    name='--source-in-place-snapshot',
+    zonal_collection='compute.zoneInPlaceSnapshots',
+    regional_collection='compute.regionInPlaceSnapshots',
+    plural=False,
+    required=False,
+    short_help='Source in place snapshot used to create the disks.',
+    detailed_help=_DETAILED_SOURCE_IN_PLACE_SNAPSHOT_HELP,
+)
+
+SOURCE_DISK_ARG = compute_flags.ResourceArgument(
+    resource_name='source disk',
+    name='--source-disk',
+    completer=compute_completers.DisksCompleter,
+    short_help='Source disk used to create the disks. Source disk must be in'
+               ' the same zone/region as the disk to be created.',
+    detailed_help=_SOURCE_DISK_DETAILED_HELP,
+    zonal_collection='compute.disks',
+    regional_collection='compute.regionDisks',
+    required=False,
+    use_existing_default_scope=True)
