@@ -81,7 +81,8 @@ def CreatePerInstanceConfigMessage(holder,
                                    instance_ref,
                                    stateful_disks,
                                    stateful_metadata,
-                                   disk_getter=None):
+                                   disk_getter=None,
+                                   set_preserved_state=True):
   """Create per-instance config message from the given stateful disks and metadata."""
   if not disk_getter:
     disk_getter = instance_disk_getter.InstanceDiskGetter(
@@ -97,13 +98,15 @@ def CreatePerInstanceConfigMessage(holder,
     preserved_state_metadata.append(
         MakePreservedStateMetadataEntry(
             messages, key=metadata_key, value=metadata_value))
-  return messages.PerInstanceConfig(
-      name=path_simplifier.Name(six.text_type(instance_ref)),
-      preservedState=messages.PreservedState(
-          disks=messages.PreservedState.DisksValue(
-              additionalProperties=preserved_state_disks),
-          metadata=messages.PreservedState.MetadataValue(
-              additionalProperties=preserved_state_metadata)))
+  per_instance_config = messages.PerInstanceConfig(
+      name=path_simplifier.Name(six.text_type(instance_ref)))
+  if set_preserved_state:
+    per_instance_config.preservedState = messages.PreservedState(
+        disks=messages.PreservedState.DisksValue(
+            additionalProperties=preserved_state_disks),
+        metadata=messages.PreservedState.MetadataValue(
+            additionalProperties=preserved_state_metadata))
+  return per_instance_config
 
 
 def CallPerInstanceConfigUpdate(holder, igm_ref, per_instance_config_message):
@@ -185,7 +188,7 @@ def GetApplyUpdatesToInstancesRequestsZonal(holder, igm_ref, instances):
       .MinimalActionValueValuesEnum.NONE,
       mostDisruptiveAllowedAction=messages
       .InstanceGroupManagersApplyUpdatesRequest
-      .MostDisruptiveAllowedActionValueValuesEnum.RESTART)
+      .MostDisruptiveAllowedActionValueValuesEnum.REPLACE)
   return messages.ComputeInstanceGroupManagersApplyUpdatesToInstancesRequest(
       instanceGroupManager=igm_ref.Name(),
       instanceGroupManagersApplyUpdatesRequest=request,
@@ -203,7 +206,7 @@ def GetApplyUpdatesToInstancesRequestsRegional(holder, igm_ref, instances):
       .MinimalActionValueValuesEnum.NONE,
       mostDisruptiveAllowedAction=messages
       .RegionInstanceGroupManagersApplyUpdatesRequest
-      .MostDisruptiveAllowedActionValueValuesEnum.RESTART)
+      .MostDisruptiveAllowedActionValueValuesEnum.REPLACE)
   return (
       messages.ComputeRegionInstanceGroupManagersApplyUpdatesToInstancesRequest
   )(
