@@ -34,6 +34,12 @@ class ExternalVpnGateways(base.Group):
 
 
 ExternalVpnGateways.detailed_help = {
-    'brief': ('Read and manipulate Google Compute Engine External '
-              'VPN Gateways.'),
+    'DESCRIPTION': """
+        Read and manipulate external VPN gateways for Cloud VPN.
+
+        For more information about external VPN gateways, see the
+        [external VPN Gateways documentation](https://cloud.google.com/vpn/docs/concepts/key-terms#external-vpn-gateway-definition).
+
+        See also: [External VPN Gateways API](https://cloud.google.com/compute/docs/reference/rest/v1/externalVpnGateways).
+    """,
 }
