@@ -32,11 +32,11 @@ def _DetailedHelp():
           'Create a HTTP health check to monitor load balanced instances.',
       'DESCRIPTION':
           """\
-      *{command}* is used to create an HTTP non-legacy health check. HTTP
-      health checks monitor instances in a load balancer controlled by a
-      target pool. All arguments to the command are optional except for the
-      name of the health check. For more information on load balancing, see
-      [](https://cloud.google.com/compute/docs/load-balancing-and-autoscaling/)
+      *{command}* is used to create a non-legacy health check using the HTTP
+      protocol. You can use this health check for Google Cloud Platform load
+      balancers or for managed instance group autohealing. For more information,
+      see the health checks overview at:
+      [](https://cloud.google.com/load-balancing/docs/health-check-concepts)
       """,
   }
 
@@ -118,7 +118,7 @@ def _Run(args, holder, include_l7_internal_load_balancing, include_log_config):
   return client.MakeRequests([(collection, 'Insert', request)])
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Create(base.CreateCommand):
   """Create a HTTP health check."""
 
@@ -138,7 +138,13 @@ class Create(base.CreateCommand):
                 self._include_log_config)
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class CreateAlpha(Create):
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class CreateBeta(Create):
 
   _include_log_config = True
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class CreateAlpha(CreateBeta):
+
+  pass
