@@ -374,7 +374,8 @@ def _RunCreate(compute_api,
                support_kms=False,
                support_min_node_cpu=False,
                support_confidential_compute=False,
-               support_location_hint=False):
+               support_location_hint=False,
+               support_private_ipv6_google_access=False):
   """Common routine for creating instance template.
 
   This is shared between various release tracks.
@@ -389,7 +390,9 @@ def _RunCreate(compute_api,
         sole tenancy overcommit is supported.
       support_confidential_compute: Indicate whether confidential compute is
         supported.
-      support_location_hint: Indicate whether location hint is supported
+      support_location_hint: Indicate whether location hint is supported.
+      support_private_ipv6_google_access: Indicate whether private ipv6 google
+        access is supported.
 
   Returns:
       A resource object dispatched by display.Displayer().
@@ -588,6 +591,13 @@ def _RunCreate(compute_api,
     instance_template.properties.confidentialInstanceConfig = (
         confidential_instance_config_message)
 
+  if (support_private_ipv6_google_access and
+      args.private_ipv6_google_access_type is not None):
+    instance_template.properties.privateIpv6GoogleAccess = (
+        instances_flags.GetPrivateIpv6GoogleAccessTypeFlagMapperForTemplate(
+            client.messages).GetEnumForChoice(
+                args.private_ipv6_google_access_type))
+
   request = client.messages.ComputeInstanceTemplatesInsertRequest(
       instanceTemplate=instance_template,
       project=instance_template_ref.project)
@@ -620,6 +630,7 @@ class Create(base.CreateCommand):
   _support_kms = True
   _support_min_node_cpu = False
   _support_location_hint = False
+  _support_private_ipv6_google_access = False
 
   @classmethod
   def Args(cls, parser):
@@ -649,8 +660,9 @@ class Create(base.CreateCommand):
         support_source_instance=self._support_source_instance,
         support_kms=self._support_kms,
         support_min_node_cpu=self._support_min_node_cpu,
-        support_location_hint=self._support_location_hint
-    )
+        support_location_hint=self._support_location_hint,
+        support_private_ipv6_google_access=self
+        ._support_private_ipv6_google_access)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
@@ -672,6 +684,7 @@ class CreateBeta(Create):
   _support_resource_policy = True
   _support_min_node_cpu = True
   _support_location_hint = False
+  _support_private_ipv6_google_access = True
 
   @classmethod
   def Args(cls, parser):
@@ -686,6 +699,8 @@ class CreateBeta(Create):
         support_location_hint=cls._support_location_hint
     )
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.BETA)
+    instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
+        parser, utils.COMPUTE_BETA_API_VERSION)
 
   def Run(self, args):
     """Creates and runs an InstanceTemplates.Insert request.
@@ -703,7 +718,9 @@ class CreateBeta(Create):
         support_source_instance=self._support_source_instance,
         support_kms=self._support_kms,
         support_min_node_cpu=self._support_min_node_cpu,
-        support_location_hint=self._support_location_hint)
+        support_location_hint=self._support_location_hint,
+        support_private_ipv6_google_access=self
+        ._support_private_ipv6_google_access)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -726,6 +743,7 @@ class CreateAlpha(Create):
   _support_min_node_cpu = True
   _support_confidential_compute = True
   _support_location_hint = True
+  _support_private_ipv6_google_access = True
 
   @classmethod
   def Args(cls, parser):
@@ -743,6 +761,8 @@ class CreateAlpha(Create):
     instances_flags.AddMinCpuPlatformArgs(parser, base.ReleaseTrack.ALPHA)
     instances_flags.AddConfidentialComputeArgs(parser)
     instance_templates_flags.AddMeshModeConfigArgs(parser)
+    instances_flags.AddPrivateIpv6GoogleAccessArgForTemplate(
+        parser, utils.COMPUTE_ALPHA_API_VERSION)
 
   def Run(self, args):
     """Creates and runs an InstanceTemplates.Insert request.
@@ -761,7 +781,9 @@ class CreateAlpha(Create):
         support_kms=self._support_kms,
         support_min_node_cpu=self._support_min_node_cpu,
         support_confidential_compute=self._support_confidential_compute,
-        support_location_hint=self._support_location_hint)
+        support_location_hint=self._support_location_hint,
+        support_private_ipv6_google_access=self
+        ._support_private_ipv6_google_access)
 
 
 DETAILED_HELP = {
