@@ -77,7 +77,7 @@ class Update(base.UpdateCommand):
 
     autoscaling_group = flags.AddClusterAutoscalingFlags(group, hidden=False)
     flags.AddNodePoolAutoprovisioningFlag(autoscaling_group, hidden=False)
-    flags.AddWorkloadMetadataFromNodeFlag(group)
+    flags.AddWorkloadMetadataFlag(group)
 
     surge_upgrade_group = group.add_argument_group('Upgrade settings')
     flags.AddSurgeUpgradeFlag(surge_upgrade_group, for_node_pool=True)
@@ -92,6 +92,7 @@ class Update(base.UpdateCommand):
         node_locations=args.node_locations,
         max_nodes=args.max_nodes,
         min_nodes=args.min_nodes,
+        workload_metadata=args.workload_metadata,
         workload_metadata_from_node=args.workload_metadata_from_node,
         enable_autoprovisioning=args.enable_autoprovisioning,
         max_surge_upgrade=args.max_surge_upgrade,
@@ -156,10 +157,12 @@ class UpdateBeta(Update):
     flags.AddSurgeUpgradeFlag(surge_upgrade_group, for_node_pool=True)
     flags.AddMaxUnavailableUpgradeFlag(surge_upgrade_group, for_node_pool=True)
 
-    flags.AddWorkloadMetadataFromNodeFlag(group, use_mode=False)
+    flags.AddWorkloadMetadataFlag(group, use_mode=False)
 
     flags.AddNodePoolLocationsFlag(group)
 
+    flags.AddSystemConfigFlag(group, hidden=True)
+
   def ParseUpdateNodePoolOptions(self, args):
     flags.ValidateSurgeUpgradeSettings(args)
     ops = api_adapter.UpdateNodePoolOptions(
@@ -169,10 +172,12 @@ class UpdateBeta(Update):
         max_nodes=args.max_nodes,
         min_nodes=args.min_nodes,
         enable_autoprovisioning=args.enable_autoprovisioning,
+        workload_metadata=args.workload_metadata,
         workload_metadata_from_node=args.workload_metadata_from_node,
         node_locations=args.node_locations,
         max_surge_upgrade=args.max_surge_upgrade,
-        max_unavailable_upgrade=args.max_unavailable_upgrade)
+        max_unavailable_upgrade=args.max_unavailable_upgrade,
+        system_config_from_file=args.system_config_from_file)
     return ops
 
 
@@ -196,10 +201,12 @@ class UpdateAlpha(Update):
     flags.AddSurgeUpgradeFlag(surge_upgrade_group, for_node_pool=True)
     flags.AddMaxUnavailableUpgradeFlag(surge_upgrade_group, for_node_pool=True)
 
-    flags.AddWorkloadMetadataFromNodeFlag(group, use_mode=False)
+    flags.AddWorkloadMetadataFlag(group, use_mode=False)
 
     flags.AddNodePoolLocationsFlag(group)
 
+    flags.AddSystemConfigFlag(group, hidden=False)
+
   def ParseUpdateNodePoolOptions(self, args):
     flags.ValidateSurgeUpgradeSettings(args)
     ops = api_adapter.UpdateNodePoolOptions(
@@ -209,10 +216,12 @@ class UpdateAlpha(Update):
         max_nodes=args.max_nodes,
         min_nodes=args.min_nodes,
         enable_autoprovisioning=args.enable_autoprovisioning,
+        workload_metadata=args.workload_metadata,
         workload_metadata_from_node=args.workload_metadata_from_node,
         node_locations=args.node_locations,
         max_surge_upgrade=args.max_surge_upgrade,
-        max_unavailable_upgrade=args.max_unavailable_upgrade)
+        max_unavailable_upgrade=args.max_unavailable_upgrade,
+        system_config_from_file=args.system_config_from_file)
     return ops
 
 
