@@ -12,7 +12,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""gcloud dns managed-zone update command."""
+"""gcloud dns policy update command."""
 
 from __future__ import absolute_import
 from __future__ import division
@@ -27,6 +27,15 @@ from googlecloudsdk.command_lib.dns import util as command_util
 from googlecloudsdk.core import log
 
 
+def _AddArgsCommon(parser):
+  flags.GetPolicyDescriptionArg().AddToParser(parser)
+  flags.GetPolicyNetworksArg().AddToParser(parser)
+  flags.GetPolicyInboundForwardingArg().AddToParser(parser)
+  flags.GetPolicyAltNameServersArg().AddToParser(parser)
+  flags.GetPolicyLoggingArg().AddToParser(parser)
+  flags.GetPolicyPrivateAltNameServersArg().AddToParser(parser)
+
+
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class UpdateGA(base.UpdateCommand):
   """Update an existing Cloud DNS policy.
@@ -43,7 +52,7 @@ class UpdateGA(base.UpdateCommand):
 
   def _FetchPolicy(self, policy_ref, api_version):
     """Get policy to be Updated."""
-    client = apis.GetClientInstance('dns', api_version)
+    client = util.GetApiClient(api_version)
     m = apis.GetMessagesModule('dns', api_version)
     get_request = m.DnsPoliciesGetRequest(
         policy=policy_ref.Name(), project=policy_ref.project)
@@ -51,88 +60,14 @@ class UpdateGA(base.UpdateCommand):
 
   @staticmethod
   def Args(parser):
-    UpdateGA.ArgsVersioned(parser, version='v1')
-
-  @staticmethod
-  def ArgsVersioned(parser, version):
     resource_args.AddPolicyResourceArg(
-        parser,
-        verb=' to update.',
-        api_version=version)
-    flags.GetPolicyDescriptionArg().AddToParser(parser)
-    flags.GetPolicyNetworksArg().AddToParser(parser)
-    flags.GetPolicyInboundForwardingArg().AddToParser(parser)
-    flags.GetPolicyAltNameServersnArg().AddToParser(parser)
+        parser, verb='to update', api_version='v1')
+    _AddArgsCommon(parser)
     parser.display_info.AddFormat('json')
 
   def Run(self, args):
     api_version = util.GetApiFromTrack(self.ReleaseTrack())
-    client = apis.GetClientInstance('dns', api_version)
-    messages = apis.GetMessagesModule('dns', api_version)
-
-    # Get Policy
-    policy_ref = args.CONCEPTS.policy.Parse()
-    to_update = self._FetchPolicy(policy_ref, api_version)
-
-    if not (args.IsSpecified('networks') or args.IsSpecified('description') or
-            args.IsSpecified('enable_inbound_forwarding') or
-            args.IsSpecified('alternative_name_servers')):
-      log.status.Print('Nothing to update.')
-      return to_update
-
-    if args.IsSpecified('networks'):
-      if args.networks == ['']:
-        args.networks = []
-      to_update.networks = command_util.ParseNetworks(args.networks,
-                                                      policy_ref.project,
-                                                      api_version)
-
-    if args.IsSpecified('alternative_name_servers'):
-      if args.alternative_name_servers == ['']:
-        args.alternative_name_servers = []
-      to_update.alternativeNameServerConfig = command_util.ParseAltNameServers(
-          args.alternative_name_servers, api_version)
-
-    if args.IsSpecified('enable_inbound_forwarding'):
-      to_update.enableInboundForwarding = args.enable_inbound_forwarding
-
-    if args.IsSpecified('description'):
-      to_update.description = args.description
-
-    update_req = messages.DnsPoliciesUpdateRequest(
-        policy=to_update.name,
-        policyResource=to_update,
-        project=policy_ref.project)
-
-    updated_policy = client.policies.Update(update_req).policy
-
-    log.UpdatedResource(updated_policy.name, kind='Policy')
-
-    return updated_policy
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
-class Update(UpdateGA):
-  """Update an existing Cloud DNS policy.
-
-  Update an existing Cloud DNS policy.
-
-  ## EXAMPLES
-
-  To change the description of a policy, run:
-
-    $ {command} mypolicy --description="Hello, world!"
-
-  """
-
-  @staticmethod
-  def Args(parser):
-    UpdateGA.ArgsVersioned(parser, version='v1beta2')
-    flags.GetPolicyLoggingArg().AddToParser(parser)
-
-  def Run(self, args):
-    api_version = util.GetApiFromTrack(self.ReleaseTrack())
-    client = apis.GetClientInstance('dns', api_version)
+    client = util.GetApiClient(api_version)
     messages = apis.GetMessagesModule('dns', api_version)
 
     # Get Policy
@@ -153,11 +88,92 @@ class Update(UpdateGA):
                                                       policy_ref.project,
                                                       api_version)
 
-    if args.IsSpecified('alternative_name_servers'):
+    if args.IsSpecified('alternative_name_servers') or args.IsSpecified(
+        'private_alternative_name_servers'):
       if args.alternative_name_servers == ['']:
         args.alternative_name_servers = []
+      if args.private_alternative_name_servers == ['']:
+        args.private_alternative_name_servers = []
       to_update.alternativeNameServerConfig = command_util.ParseAltNameServers(
-          args.alternative_name_servers, api_version)
+          version=api_version,
+          server_list=args.alternative_name_servers,
+          private_server_list=args.private_alternative_name_servers)
+
+    if args.IsSpecified('enable_inbound_forwarding'):
+      to_update.enableInboundForwarding = args.enable_inbound_forwarding
+
+    if args.IsSpecified('enable_logging'):
+      to_update.enableLogging = args.enable_logging
+
+    if args.IsSpecified('description'):
+      to_update.description = args.description
+
+    update_req = messages.DnsPoliciesUpdateRequest(
+        policy=to_update.name,
+        policyResource=to_update,
+        project=policy_ref.project)
+
+    updated_policy = client.policies.Update(update_req).policy
+
+    log.UpdatedResource(updated_policy.name, kind='Policy')
+
+    return updated_policy
+
+
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class UpdateBeta(UpdateGA):
+  """Update an existing Cloud DNS policy.
+
+  Update an existing Cloud DNS policy.
+
+  ## EXAMPLES
+
+  To change the description of a policy, run:
+
+    $ {command} mypolicy --description="Hello, world!"
+
+  """
+
+  @staticmethod
+  def Args(parser):
+    resource_args.AddPolicyResourceArg(
+        parser, verb='to update', api_version='v1beta2')
+    _AddArgsCommon(parser)
+    parser.display_info.AddFormat('json')
+
+  def Run(self, args):
+    api_version = util.GetApiFromTrack(self.ReleaseTrack())
+    client = util.GetApiClient(api_version)
+    messages = apis.GetMessagesModule('dns', api_version)
+
+    # Get Policy
+    policy_ref = args.CONCEPTS.policy.Parse()
+    to_update = self._FetchPolicy(policy_ref, api_version)
+
+    if not (args.IsSpecified('networks') or args.IsSpecified('description') or
+            args.IsSpecified('enable_inbound_forwarding') or
+            args.IsSpecified('enable_logging') or
+            args.IsSpecified('alternative_name_servers')):
+      log.status.Print('Nothing to update.')
+      return to_update
+
+    if args.IsSpecified('networks'):
+      if args.networks == ['']:
+        args.networks = []
+      to_update.networks = command_util.ParseNetworks(args.networks,
+                                                      policy_ref.project,
+                                                      api_version)
+
+    if args.IsSpecified('alternative_name_servers') or args.IsSpecified(
+        'private_alternative_name_servers'):
+      if args.alternative_name_servers == ['']:
+        args.alternative_name_servers = []
+      if args.private_alternative_name_servers == ['']:
+        args.private_alternative_name_servers = []
+      to_update.alternativeNameServerConfig = command_util.ParseAltNameServers(
+          version=api_version,
+          server_list=args.alternative_name_servers,
+          private_server_list=args.private_alternative_name_servers)
 
     if args.IsSpecified('enable_inbound_forwarding'):
       to_update.enableInboundForwarding = args.enable_inbound_forwarding
@@ -177,3 +193,25 @@ class Update(UpdateGA):
     log.UpdatedResource(updated_policy.name, kind='Policy')
 
     return updated_policy
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class UpdateAlpha(UpdateBeta):
+  """Update an existing Cloud DNS policy.
+
+  Update an existing Cloud DNS policy.
+
+  ## EXAMPLES
+
+  To change the description of a policy, run:
+
+    $ {command} mypolicy --description="Hello, world!"
+
+  """
+
+  @staticmethod
+  def Args(parser):
+    resource_args.AddPolicyResourceArg(
+        parser, verb='to update', api_version='v1alpha2')
+    _AddArgsCommon(parser)
+    parser.display_info.AddFormat('json')
