@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -279,6 +279,38 @@ At least one region or region must be specified.
 For more information on default regions, see
 https://cloud.google.com/compute/docs/gcloud-compute/#set_default_zone_and_region_in_your_local_client''')
 
+    parser.add_argument(
+        '--network',
+        help='''v2alpha1 only. The network name to attach the VM's network
+            interface to.
+
+The value will be prefixed with global/networks/ unless it contains a /, in
+which case it is assumed to be a fully specified network resource URL.
+
+If unspecified, the global default network is used.''')
+
+    parser.add_argument(
+        '--subnetwork',
+        help='''v2alpha1 only. The subnetwork to use on the provided network.
+
+If the specified network is configured for custom subnet creation, the name of
+the subnetwork to attach the instance to must be specified here.
+
+The value is prefixed with regions/*/subnetworks/ unless it contains a /, in
+which case it is assumed to be a fully specified subnetwork resource URL.
+
+If the * character appears in the value, it is replaced with the region that
+the virtual machine has been allocated in.''')
+
+    parser.add_argument(
+        '--boot-disk-size',
+        type=int,
+        help='''v2alpha1 only. The size of the boot disk in GB.
+
+The boot disk size must be large enough to accomondate all Docker images from
+each action in the pipeline at the same time. If not specified, a small but
+reasonable default value is used.''')
+
   def Run(self, args):
     """This is what gets called when the user runs this command.
 
@@ -380,6 +412,21 @@ https://cloud.google.com/compute/docs/gcloud-compute/#set_default_zone_and_regio
       virtual_machine.serviceAccount.scopes.append(
           'https://www.googleapis.com/auth/devstorage.read_write')
 
+      # Attach custom network/subnetwork (if set).
+      if args.network or args.subnetwork:
+        if not virtual_machine.network:
+          virtual_machine.network = genomics_messages.Network()
+        if args.network:
+          virtual_machine.network.name = args.network
+        if args.subnetwork:
+          virtual_machine.network.subnetwork = args.subnetwork
+
+      if args.boot_disk_size is not None:
+        if args.boot_disk_size <= 0:
+          raise exceptions.GenomicsError(
+              'Boot disk size must be greater than zero.')
+        virtual_machine.bootDiskSizeGb = args.boot_disk_size
+
       # Generate paths for inputs and outputs in a shared location and put them
       # into the environment for actions based on their name.
       env = {}
@@ -397,7 +444,7 @@ https://cloud.google.com/compute/docs/gcloud-compute/#set_default_zone_and_regio
             pipeline.actions.insert(0, genomics_messages.Action(
                 imageUri=CLOUD_SDK_IMAGE,
                 commands=['/bin/sh', '-c', 'echo "%s" | base64 -d > ${%s}' %
-                          (base64.b64encode(value), name)]))
+                          (base64.b64encode(value.encode()), name)]))
           else:
             env[name] = value
 
@@ -453,9 +500,8 @@ https://cloud.google.com/compute/docs/gcloud-compute/#set_default_zone_and_regio
             raise exceptions.GenomicsError('Invalid --disk-size.')
 
         for disk in virtual_machine.disks:
-          size = disk_sizes[disk.name]
-          if size:
-            disk.sizeGb = size
+          if disk.name in disk_sizes:
+            disk.sizeGb = disk_sizes[disk.name]
 
       request = genomics_messages.RunPipelineRequest(
           pipeline=pipeline,
