@@ -23,6 +23,7 @@ from googlecloudsdk.api_lib.privateca import base as privateca_base
 from googlecloudsdk.api_lib.privateca import request_utils
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
+from googlecloudsdk.calliope.concepts import deps
 from googlecloudsdk.command_lib.kms import resource_args as kms_resource_args
 from googlecloudsdk.command_lib.privateca import flags
 from googlecloudsdk.command_lib.privateca import iam
@@ -96,7 +97,13 @@ class Create(base.CreateCommand):
                 required=True),
             presentation_specs.ResourcePresentationSpec(
                 '--reusable-config',
-                privateca_resource_args.CreateReusableConfigResourceSpec('CA'),
+                privateca_resource_args.CreateReusableConfigResourceSpec(
+                    location_fallthrough=deps.Fallthrough(
+                        function=lambda: '',
+                        hint=('location will default to the same location as '
+                              'the CA'),
+                        active=False,
+                        plural=False)),
                 'The Reusable Config containing X.509 values for this CA.',
                 flag_name_overrides={
                     'location': '',
@@ -198,4 +205,13 @@ class Create(base.CreateCommand):
     ca_response = operations.Await(operation, 'Creating Certificate Authority.')
     ca = operations.GetMessageFromResponse(ca_response,
                                            self.messages.CertificateAuthority)
+
+    log.status.Print('Creating the initial Certificate Revocation List.')
+    self.client.projects_locations_certificateAuthorities.PublishCrl(
+        self.messages
+        .PrivatecaProjectsLocationsCertificateAuthoritiesPublishCrlRequest(
+            name=ca.name,
+            publishCertificateRevocationListRequest=self.messages
+            .PublishCertificateRevocationListRequest()))
+
     log.status.Print('Created Certificate Authority [{}].'.format(ca.name))
