@@ -24,6 +24,7 @@ from googlecloudsdk.api_lib.privateca import certificate_utils
 from googlecloudsdk.api_lib.privateca import request_utils
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
+from googlecloudsdk.calliope.concepts import deps
 from googlecloudsdk.command_lib.kms import resource_args as kms_resource_args
 from googlecloudsdk.command_lib.privateca import flags
 from googlecloudsdk.command_lib.privateca import iam
@@ -137,7 +138,13 @@ class Create(base.CreateCommand):
             required=True),
         presentation_specs.ResourcePresentationSpec(
             '--reusable-config',
-            privateca_resource_args.CreateReusableConfigResourceSpec(),
+            privateca_resource_args.CreateReusableConfigResourceSpec(
+                location_fallthrough=deps.Fallthrough(
+                    function=lambda: '',
+                    hint=('location will default to the same location as the '
+                          'CA'),
+                    active=False,
+                    plural=False)),
             'The Reusable Config containing X.509 values for this CA.',
             flag_name_overrides={
                 'location': '',
@@ -212,7 +219,9 @@ class Create(base.CreateCommand):
     subject_config = flags.ParseSubjectFlags(args, is_ca=True)
     issuing_options = flags.ParseIssuingOptions(args)
     issuance_policy = flags.ParseIssuancePolicy(args)
-    reusable_config_wrapper = flags.ParseReusableConfig(args, is_ca=True)
+    reusable_config_wrapper = flags.ParseReusableConfig(args,
+                                                        ca_ref.locationsId,
+                                                        is_ca=True)
     lifetime = flags.ParseValidityFlag(args)
     labels = labels_util.ParseCreateArgs(
         args, self.messages.CertificateAuthority.LabelsValue)
