@@ -33,7 +33,7 @@ from googlecloudsdk.command_lib.util.concepts import presentation_specs
 from googlecloudsdk.core.console import progress_tracker
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Update(base.Command):
   """Update Cloud Run environment variables and other configuration settings."""
 
@@ -150,6 +150,18 @@ class Update(base.Command):
         pretty_print.Success(msg)
 
 
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class BetaUpdate(Update):
+  """Update Cloud Run environment variables and other configuration settings."""
+
+  @staticmethod
+  def Args(parser):
+    Update.Args(parser)
+
+    # Flags specific to VPCAccess
+    flags.AddVpcConnectorArg(parser)
+
+
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class AlphaUpdate(Update):
   """Update Cloud Run environment variables and other configuration settings."""
