@@ -28,6 +28,7 @@ from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core import properties
 
 
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Create(base.CreateCommand):
   r"""Create a new secret.
 
@@ -113,8 +114,7 @@ class Create(base.CreateCommand):
     labels_util.AddCreateLabelsFlags(parser)
 
   def Run(self, args):
-    messages = secrets_api.GetMessages(
-        version=secrets_util.GetVersionFromReleasePath(self.ReleaseTrack()))
+    messages = secrets_api.GetMessages()
     secret_ref = args.CONCEPTS.secret.Parse()
     data = secrets_util.ReadFileOrStdin(args.data_file)
     labels = labels_util.ParseCreateArgs(args, messages.Secret.LabelsValue)
@@ -161,21 +161,61 @@ class Create(base.CreateCommand):
     if args.data_file == '':  # pylint: disable=g-explicit-bool-comparison
       raise exceptions.BadFileException(self.EMPTY_DATA_FILE_MESSAGE)
     # Create the secret
-    response = secrets_api.Secrets(
-        version=secrets_util.GetVersionFromReleasePath(
-            self.ReleaseTrack())).Create(
-                secret_ref,
-                labels=labels,
-                locations=locations,
-                policy=replication_policy)
+    response = secrets_api.Secrets().Create(
+        secret_ref,
+        labels=labels,
+        locations=locations,
+        policy=replication_policy)
 
     if data:
-      version = secrets_api.Secrets(
-          version=secrets_util.GetVersionFromReleasePath(
-              self.ReleaseTrack())).AddVersion(secret_ref, data)
+      version = secrets_api.Secrets().AddVersion(secret_ref, data)
       version_ref = secrets_args.ParseVersionRef(version.name)
       secrets_log.Versions().Created(version_ref)
     else:
       secrets_log.Secrets().Created(secret_ref)
 
     return response
+
+
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class CreateBeta(Create):
+  r"""Create a new secret.
+
+  Create a secret with the given name and creates a secret version with the
+  given data, if any. If a secret already exists with the given name, this
+  command will return an error.
+
+  ## EXAMPLES
+
+  Create a secret with an automatic replication policy without creating any
+  versions:
+
+    $ {command} my-secret --replication-policy=automatic
+
+  Create a new secret named 'my-secret' with an automatic replication policy
+  and data from a file:
+
+    $ {command} my-secret --data-file=/tmp/secret
+    --replication-policy=automatic
+
+  Create a new secret named 'my-secret' in 'us-central1' with data from a file:
+
+    $ {command} my-secret --data-file=/tmp/secret
+    --replication-policy=user-managed \
+        --locations=us-central1
+
+  Create a new secret named 'my-secret' in 'us-central1' and 'us-east1' with
+  the value "s3cr3t":
+
+    $ echo "s3cr3t" | {command} my-secret --data-file=- \
+        --replication-policy=user-managed --locations=us-central1,us-east1
+  """
+
+  @staticmethod
+  def Args(parser):
+    secrets_args.AddSecret(
+        parser, purpose='to create', positional=True, required=True)
+    secrets_args.AddLocations(parser, resource='secret')
+    secrets_args.AddDataFile(parser)
+    secrets_args.AddPolicy(parser)
+    labels_util.AddCreateLabelsFlags(parser)
