@@ -22,12 +22,8 @@ from googlecloudsdk.calliope import base
 
 
 @base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
 class Workflows(base.Group):
   """Manage your Cloud Workflows resources."""
 
   category = base.TOOLS_CATEGORY
-
-  def Filter(self, context, args):
-    del context, args
-    base.DisableUserProjectQuota()
