@@ -76,12 +76,12 @@ _CH_SYNOPSIS = """
       -d ("user"|"serviceAccount"|"domain"|"group"):id
       -d ("allUsers"|"allAuthenticatedUsers")
 
-  Note: The "iam ch" command does not support changing IAM policies with
+  NOTE: The "iam ch" command does not support changing Cloud IAM policies with
   bindings that contain conditions. As such, "iam ch" cannot be used to add
   conditions to a policy or to change the policy of a resource that already
   contains conditions. See additional details below.
 
-  Note: The "gsutil iam" command disallows using project convenience groups
+  NOTE: The "gsutil iam" command does not allow using project convenience groups
   (projectOwner, projectEditor, projectViewer) as the first segment of a binding
   because these groups go against the principle of least privilege.
 
@@ -89,77 +89,73 @@ _CH_SYNOPSIS = """
 
 _GET_DESCRIPTION = """
 <B>GET</B>
-  The ``iam get`` command gets the IAM policy for a bucket or object, which you
+  The ``iam get`` command gets the Cloud IAM policy for a bucket or object, which you
   can save and edit for use with the ``iam set`` command.
 
-  For example:
+  The following examples save the bucket or object's Cloud IAM policy to a text file:
 
     gsutil iam get gs://example > bucket_iam.txt
     gsutil iam get gs://example/important.txt > object_iam.txt
 
-  The IAM policy returned by ``iam get`` includes the etag of the IAM policy and
-  will be used in the precondition check for ``iam set``, unless the etag is
-  overridden by setting the ``iam set -e`` option.
+  The Cloud IAM policy returned by ``iam get`` includes an etag. The etag is used in the
+  precondition check for ``iam set`` unless you override it using
+  ``iam set -e``.
 """
 
 _SET_DESCRIPTION = """
 <B>SET</B>
-  The ``iam set`` command sets the IAM policy for one or more buckets and / or
-  objects. It overwrites the current IAM policy that exists on a bucket (or
-  object) with the policy specified in the input file. The ``iam set`` command
-  takes as input a file with an IAM policy in the format of the output
-  generated by ``iam get``.
+  The ``iam set`` command sets a Cloud IAM policy on one or more buckets or objects,
+  overwriting the existing policy on those buckets or objects. For an example of the correct
+  formatting for a Cloud IAM policy, see the output of the ``iam get`` command.
 
-  The ``iam ch`` command can be used to edit an existing policy. It works
-  correctly in the presence of concurrent updates. You may also do this
-  manually by using the -e flag and overriding the etag returned in ``iam get``.
-  Specifying -e with an empty string (i.e. ``gsutil iam set -e '' ...``) will
-  instruct gsutil to skip the precondition check when setting the IAM policy.
+  You can use the ``iam ch`` command to edit an existing policy, even in the
+  presence of concurrent updates. You can also edit the policy concurrently using
+  the ``-e`` flag to override the Cloud IAM policy's etag. Specifying ``-e`` with an
+  empty string (i.e. ``gsutil iam set -e '' ...``) instructs gsutil to skip the precondition
+  check when setting the Cloud IAM policy.
 
-  If you wish to set an IAM policy on a large number of objects, you may want
-  to use the gsutil -m option for concurrent processing. The following command
-  will apply iam.txt to all objects in the "cats" bucket.
+  When you set a Cloud IAM policy on a large number of objects, you should use the
+  gsutil ``-m`` option for concurrent processing. The following command
+  applies ``iam.txt`` to all objects in the ``dogs`` bucket:
 
-    gsutil -m iam set -r iam.txt gs://cats
+    gsutil -m iam set -r iam.txt gs://dogs
 
-  Note that only object-level IAM applications are parallelized; you do not
-  gain any additional performance when applying an IAM policy to a large
-  number of buckets with the -m flag.
+  Note that only object-level operations are parallelized; setting a Cloud IAM policy
+  on a large number of buckets with the ``-m`` flag does not improve performance.
 
 <B>SET OPTIONS</B>
-  The ``set`` sub-command has the following options
+  The ``set`` sub-command has the following options:
 
-    -R, -r      Performs ``iam set`` recursively to all objects under the
-                specified bucket.
+  -R, -r      Performs ``iam set`` recursively on all objects under the
+              specified bucket.
 
-    -a          Performs ``iam set`` request on all object versions.
+  -a          Performs ``iam set`` on all object versions.
 
-    -e <etag>   Performs the precondition check on each object with the
-                specified etag before setting the policy.
+  -e <etag>   Performs the precondition check on each object with the
+              specified etag before setting the policy. You can retrieve the policy's
+              etag using ``iam get``.
 
-    -f          Default gsutil error handling is fail-fast. This flag
-                changes the request to fail-silent mode. This is implicitly
-                set when invoking the gsutil -m option.
+  -f          The default gsutil error-handling mode is fail-fast. This flag
+              changes the request to fail-silent mode. This option is implicitly
+              set when you use the gsutil ``-m`` option.
 """
 
 _CH_DESCRIPTION = """
 <B>CH</B>
-  The ``iam ch`` command incrementally updates IAM policies. You may specify
-  multiple access grants and removals in a single command invocation, which
-  will be batched and applied as a whole to each url via an IAM patch.
-  The patch will be constructed by applying each access grant or removal in the
-  order in which they appear in the command line arguments. Each access change
-  specifies a member and the role that will be either granted or revoked.
+  The ``iam ch`` command incrementally updates Cloud IAM policies. You can specify
+  multiple access grants or removals in a single command. The access changes are
+  applied as a batch to each url in the order in which they appear in the
+  command line arguments. Each access change specifies a member and a role that
+  is either granted or revoked.
 
-  The gsutil -m option may be set to handle object-level operations more
-  efficiently.
+  You can use gsutil ``-m`` to handle object-level operations in parallel.
 
-  Note: The ``iam ch`` command may NOT be used to change the IAM policy of a
+  NOTE: The ``iam ch`` command cannot be used to change the Cloud IAM policy of a
   resource that contains conditions in its policy bindings. Attempts to do so
-  will result in an error. To change the IAM policy of such a resource, you can
-  perform a read-modify-write operation by using ``gsutil iam get`` to save the
-  policy to a file, editing the file, and using ``gsutil iam set`` to set the
-  updated policy.
+  result in an error. To change the Cloud IAM policy of such a resource, you can
+  perform a read-modify-write operation by saving the policy to a file using
+  ``iam get``, editing the file, and setting the updated policy using
+  ``iam set``.
 
 <B>CH EXAMPLES</B>
   Examples for the ``ch`` sub-command:
@@ -196,20 +192,27 @@ _CH_DESCRIPTION = """
     gsutil iam ch -d user:john.doe@example.com gs://ex-bucket
 
 <B>CH OPTIONS</B>
-  The ``ch`` sub-command has the following options
+  The ``ch`` sub-command has the following options:
 
-    -R, -r      Performs ``iam ch`` recursively to all objects under the
-                specified bucket.
+  -d          Removes roles granted to the specified member.
 
-    -f          Default gsutil error handling is fail-fast. This flag
-                changes the request to fail-silent mode. This is implicitly
-                set when invoking the gsutil -m option.
+  -R, -r      Performs ``iam ch`` recursively to all objects under the
+              specified bucket.
+
+  -f          The default gsutil error-handling mode is fail-fast. This flag
+              changes the request to fail-silent mode. This is implicitly
+              set when you invoke the gsutil ``-m`` option.
 """
 
 _SYNOPSIS = (_SET_SYNOPSIS + _GET_SYNOPSIS.lstrip('\n') +
              _CH_SYNOPSIS.lstrip('\n') + '\n\n')
 
 _DESCRIPTION = """
+  Cloud Identity and Access Management (Cloud IAM) allows you to control who has
+  access to the resources in your Google Cloud project. For more information,
+  see `Cloud Identity and Access Management
+  <https://cloud.google.com/storage/docs/access-control/iam>`_.
+  
   The iam command has three sub-commands:
 """ + '\n'.join([_GET_DESCRIPTION, _SET_DESCRIPTION, _CH_DESCRIPTION])
 
@@ -372,6 +375,10 @@ class IamCommand(Command):
     gsutil_api = GetCloudApiInstance(self, thread_state=thread_state)
 
     if storage_url.IsBucket():
+      # Temporarily setting version manually on bucket IAM policies, as
+      # setting version on objects incorrectly causes the API to throw an
+      # error. See b/140734851.
+      policy.version = IAM_POLICY_VERSION
       gsutil_api.SetBucketIamPolicy(storage_url.bucket_name,
                                     policy,
                                     provider=storage_url.scheme)
@@ -605,18 +612,14 @@ class IamCommand(Command):
       raise ArgumentException('Specified IAM policy file "%s" does not exist.' %
                               file_url)
     except ValueError as e:
-      self.logger.debug('Invalid IAM policy file, ValueError:\n', e)
+      self.logger.debug('Invalid IAM policy file, ValueError:\n%s', e)
       raise ArgumentException('Invalid IAM policy file "%s".' % file_url)
 
     bindings = policy.get('bindings', [])
     if not force_etag:
       etag = policy.get('etag', '')
 
-    policy_json = json.dumps({
-        'bindings': bindings,
-        'etag': etag,
-        'version': IAM_POLICY_VERSION
-    })
+    policy_json = json.dumps({'bindings': bindings, 'etag': etag})
     try:
       policy = protojson.decode_message(apitools_messages.Policy, policy_json)
     except DecodeError:
